@@ -153,10 +153,12 @@ def FormBuilder(data,extra_tooling=False,passThruText=None):
                                 break
                             elif isinstance(line,str) and line.lower() in ['showkeys','show keys']:
                                 keys_index(data)
+                                '''
                                 done=True
                                 finalize=True
                                 skip_review=True
-                                break
+                                '''
+                                continue
                             elif line.lower() == 'd':
                                 line='\n'
                             else:
@@ -181,32 +183,45 @@ def FormBuilder(data,extra_tooling=False,passThruText=None):
                             else:
                                 continue
                 else:
-                    passThru=['gotoi','goto i','gotok','goto k','showkeys','show keys','ff','finalize','finish']
-                    cmd=Prompt.__init2__(None,func=lambda text,data:FormBuilderMkText(text,data,passThru=passThru,PassThru=True),ptext=f"{passThruText} You(m):{item.get(k)}|Default(d):{data[k]['default']} Field:{str(k)}",helpText=f'{ht}',data=data[k]['type'])
-                    if cmd in [None,]:
-                        return
-                    elif isinstance(cmd,list) and [i.lower() for i in cmd] in [['gotoi',],['goto i']]:
-                        GOTOK=setGOTOK(data)
-                        while GOTOK not in list(data.keys()):
+                    if_continue=False
+                    while True:
+                        passThru=['gotoi','goto i','gotok','goto k','showkeys','show keys','ff','finalize','finish']
+                        cmd=Prompt.__init2__(None,func=lambda text,data:FormBuilderMkText(text,data,passThru=passThru,PassThru=True),ptext=f"{passThruText} You(m):{item.get(k)}|Default(d):{data[k]['default']} Field:{str(k)}",helpText=f'{ht}',data=data[k]['type'])
+                        if cmd in [None,]:
+                            return
+                        elif isinstance(cmd,list) and [i.lower() for i in cmd] in [['gotoi',],['goto i']]:
                             GOTOK=setGOTOK(data)
-                        continue
-                    elif isinstance(cmd,list) and [i.lower() for i in cmd] in [['gotok',],['goto k']]:
-                        GOTOK=setGOTOK_str(data)
-                        while GOTOK not in list(data.keys()):
+                            while GOTOK not in list(data.keys()):
+                                GOTOK=setGOTOK(data)
+                            if_continue=True
+                            break
+
+                        elif isinstance(cmd,list) and [i.lower() for i in cmd] in [['gotok',],['goto k']]:
                             GOTOK=setGOTOK_str(data)
-                        continue
-                    elif isinstance(cmd,str) and cmd.lower() in ['gotoi','goto i']:
-                        GOTOK=setGOTOK(GOTOK)
-                        while GOTOK not in list(data.keys()):
+                            while GOTOK not in list(data.keys()):
+                                GOTOK=setGOTOK_str(data)
+                            if_continue=True
+                            break
+
+                        elif isinstance(cmd,str) and cmd.lower() in ['gotoi','goto i']:
                             GOTOK=setGOTOK(GOTOK)
-                        continue
-                    elif isinstance(cmd,str) and cmd.lower() in ['gotok','goto k']:
-                        GOTOK=setGOTOK_str(data)
-                        while GOTOK not in list(data.keys()):
+                            while GOTOK not in list(data.keys()):
+                                GOTOK=setGOTOK(GOTOK)
+                            if_continue=True
+                            break
+
+                        elif isinstance(cmd,str) and cmd.lower() in ['gotok','goto k']:
                             GOTOK=setGOTOK_str(data)
-                        continue
-                    elif isinstance(cmd,str) and cmd.lower() in ['showkeys','show keys']:
-                        keys_index(data)
+                            while GOTOK not in list(data.keys()):
+                                GOTOK=setGOTOK_str(data)
+                            if_continue=True
+                            break
+
+                        elif isinstance(cmd,str) and cmd.lower() in ['showkeys','show keys']:
+                            keys_index(data)
+                            continue
+                        break
+                    if if_continue:
                         continue
                 if cmd in [None,]:
                     return
